@@ -16,6 +16,21 @@ def _flatten_schema(fields: List[StructType], prefix: str = None) -> List[str]:
     return flat
 
 
+def flatten(df: DataFrame) -> DataFrame:
+    """
+    Flatten dataframe with nested structs and trasform all fields into columns.
+    """
+    cols_map = [
+        (x, x.replace(".", "_").lower())
+        for x in _flatten_schema(df.schema.fields)
+    ]
+    sel_list = [
+        F.col(old_col).alias(new_col) for (old_col, new_col) in cols_map
+    ]
+    df = df.select(*sel_list)
+    return df
+
+
 def to_hive_format(df: DataFrame) -> DataFrame:
     """
     Transform Avro structure into exploded format
@@ -24,8 +39,4 @@ def to_hive_format(df: DataFrame) -> DataFrame:
     df = df.select("*", "avro.metadata", "avro.signalData").drop("avro")
     df = df.withColumn("signalData", F.explode("signalData"))
 
-    cols_map = [(x, x.replace(".", "_").lower()) for x in _flatten_schema(df.schema.fields)]
-    sel_list = [F.col(old_col).alias(new_col) for (old_col, new_col) in cols_map]
-    df = df.select(*sel_list)
-
-    return df
+    return flatten(df)
